==> haskell-hslua-core-2.3.1-42-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-core
version:              2.3.1
visibility:           public
id:                   hslua-core-2.3.1-IyI9OufFuBtHH3ZMlxCaYs
key:                  hslua-core-2.3.1-IyI9OufFuBtHH3ZMlxCaYs
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Bindings to Lua, an embeddable scripting language
description:
    Wrappers and helpers to bridge Haskell and
    <https://www.lua.org/ Lua>.

    It builds upon the /lua/ package, which allows to bundle
    a Lua interpreter with a Haskell program.

category:             Foreign
abi:                  877e272d4c40ab69c063cf3969ce31a6
exposed:              True
exposed-modules:
    HsLua.Core, HsLua.Core.Closures, HsLua.Core.Debug,
    HsLua.Core.Error, HsLua.Core.Package, HsLua.Core.Run,
    HsLua.Core.Trace, HsLua.Core.Types, HsLua.Core.Unsafe,
    HsLua.Core.Userdata, HsLua.Core.Utf8,
    Lua from lua-2.3.2-BzFGgQ9DVIwCkQiWvOAVka:Lua

hidden-modules:
    HsLua.Core.Auxiliary HsLua.Core.Primary HsLua.Core.Warn

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-core-2.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-core-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-core
hs-libraries:         HShslua-core-2.3.1-IyI9OufFuBtHH3ZMlxCaYs
depends:
    base-4.16.4.0 bytestring-0.11.4.0 exceptions-0.10.4
    lua-2.3.2-BzFGgQ9DVIwCkQiWvOAVka mtl-2.2.2 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-hslua-core/html/hslua-core.haddock
haddock-html:         /usr/share/doc/haskell-hslua-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-core-2.3.1-52.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-core
version:              2.3.1
visibility:           public
id:                   hslua-core-2.3.1-8C0aoFQaOrXKTRw02glTvW
key:                  hslua-core-2.3.1-8C0aoFQaOrXKTRw02glTvW
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Bindings to Lua, an embeddable scripting language
description:
    Wrappers and helpers to bridge Haskell and
    <https://www.lua.org/ Lua>.

    It builds upon the /lua/ package, which allows to bundle
    a Lua interpreter with a Haskell program.

category:             Foreign
abi:                  36385d237020a7364a298e4e66634966
exposed:              True
exposed-modules:
    HsLua.Core, HsLua.Core.Closures, HsLua.Core.Debug,
    HsLua.Core.Error, HsLua.Core.Package, HsLua.Core.Run,
    HsLua.Core.Trace, HsLua.Core.Types, HsLua.Core.Unsafe,
    HsLua.Core.Userdata, HsLua.Core.Utf8,
    Lua from lua-2.3.3-LJjSIwUOXmTId3gJRxtLsQ:Lua

hidden-modules:
    HsLua.Core.Auxiliary HsLua.Core.Primary HsLua.Core.Warn

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-core-2.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-core-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-core
hs-libraries:         HShslua-core-2.3.1-8C0aoFQaOrXKTRw02glTvW
depends:
    base-4.16.4.0 bytestring-0.11.4.0 exceptions-0.10.4
    lua-2.3.3-LJjSIwUOXmTId3gJRxtLsQ mtl-2.2.2 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-hslua-core/html/hslua-core.haddock
haddock-html:         /usr/share/doc/haskell-hslua-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
